package es.rickyepoderi.springboot.rest;

import io.swagger.v3.jaxrs2.integration.JaxrsOpenApiContextBuilder;
import io.swagger.v3.jaxrs2.integration.resources.OpenApiResource;
import io.swagger.v3.oas.integration.OpenApiConfigurationException;
import io.swagger.v3.oas.integration.SwaggerConfiguration;
import io.swagger.v3.oas.models.OpenAPI;
import io.swagger.v3.oas.models.info.Info;
import java.util.Collections;
import javax.servlet.ServletConfig;
import javax.ws.rs.ApplicationPath;
import javax.ws.rs.core.Context;
import org.glassfish.jersey.server.ResourceConfig;
import org.springframework.stereotype.Component;

/**
 *
 * @author rmartinc
 */
@ApplicationPath("api")
@Component
public class RestApplication extends ResourceConfig {

    @Context
    private ServletConfig servletConfig;
    
    // it doesn't work with standard Application, why?
    //https://stackoverflow.com/questions/47237180/how-to-register-resource-with-javax-ws-rs-core-applicaiton-in-spring-boot-starte
    public RestApplication() {
        register(HelloEndpoint.class);
        register(OpenApiResource.class);
        register(RolesAuthorizationFilter.class);
        
        try {
            new JaxrsOpenApiContextBuilder()
                    .servletConfig(servletConfig)
                    .application(this)
                    .openApiConfiguration(new SwaggerConfiguration()
                            .openAPI(new OpenAPI()
                                    .info(new Info()
                                            .title("Hello App")
                                            .description("Sample Spring Boot Hello App")
                                            .version("0.0.1-SNAPSHOT")))
                            .prettyPrint(true)
                            .resourcePackages(Collections.singleton(HelloEndpoint.class.getPackage().getName())))
                    .buildContext(true);
        } catch (OpenApiConfigurationException e) {
            throw new RuntimeException(e);
        }
    }
}
